<?php

class Quivers_Integration_Model_Order extends Mage_Sales_Model_Order
{
	    /**
     * Check for order status in Quivers and validate
     *  the possibility to unhold the order.
     *
     * @return Mage_Sales_Model_Order
     * @throws Mage_Core_Exception
     */

    public function validate_order_status_for_unhold()
    {
    	$quiversAPIKey = Mage::getStoreConfig('quivers_integration/settings/quivers_api_key');
        $quiversSandbox = Mage::getStoreConfig('quivers_integration/settings/quivers_sandbox_enabled');
        $orderUpdateValidateUrl = 'https://konect.quiverstest.com/clients/validate/order/';
        if($quiversSandbox == 0) {
            $orderUpdateValidateUrl = "https://konect.quivers.com/clients/validate/order/";
        }

        $payload = array(
        	'client_type'=> 'MAGENTO1',
        	'order_number'=> $this->getIncrementId(),
        	);

        // Mage::log($payload);
        $ch = curl_init($orderUpdateValidateUrl);
        # Setup request to send json via POST.
        $orderData = json_encode($payload);
        curl_setopt( $ch, CURLOPT_POSTFIELDS, $orderData);
        curl_setopt( $ch, CURLOPT_HTTPHEADER, array(
        	'Content-Type:application/json',
        	'Authorization: apikey '.$quiversAPIKey
        	)
        );

        # Return response instead of printing.
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
        # Send request.
        $result = curl_exec($ch);
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        if($httpcode!=200) {
        	Mage::throwException(Mage::helper('sales')->__('Unhold action is not available.'));
        }

        $responseDecoded = json_decode($result, true);
        foreach ($responseDecoded as $key => $item) {
        	if( $item['Value'] == 60 && $item['performed_by'] == 'Retailer' ) {
				Mage::throwException(Mage::helper('sales')->__('Unhold action is not available. This order is already shipped by a Retailer'));        		
        	}
        }
    }

    public function quiversSendOrderUpdateEmail($notifyCustomer = true, $comment = '')
    {
        $this->quiversQueueOrderUpdateEmail($notifyCustomer, $comment, true);
        return $this;
    }

    public function quiversQueueOrderUpdateEmail($notifyCustomer = true, $comment = '', $forceMode = false)
    {
        $storeId = $this->getStore()->getId();

        if (!Mage::helper('sales')->canSendOrderCommentEmail($storeId)) {
            return $this;
        }
        // Get the destination email addresses to send copies to
        $copyTo = $this->_getEmails(self::XML_PATH_UPDATE_EMAIL_COPY_TO);
        $copyMethod = Mage::getStoreConfig(self::XML_PATH_UPDATE_EMAIL_COPY_METHOD, $storeId);
        // Check if at least one recipient is found
        if (!$notifyCustomer && !$copyTo) {
            return $this;
        }

        // Retrieve corresponding email template id and customer name
        if ($this->getCustomerIsGuest()) {
            $templateId = Mage::getStoreConfig(self::XML_PATH_UPDATE_EMAIL_GUEST_TEMPLATE, $storeId);
            $customerName = $this->getBillingAddress()->getName();
        } else {
            $templateId = Mage::getStoreConfig(self::XML_PATH_UPDATE_EMAIL_TEMPLATE, $storeId);
            $customerName = $this->getCustomerName();
        }

        /** @var $mailer Mage_Core_Model_Email_Template_Mailer */
        $mailer = Mage::getModel('core/email_template_mailer');
        if ($notifyCustomer) {
            /** @var $emailInfo Mage_Core_Model_Email_Info */
            $emailInfo = Mage::getModel('core/email_info');
            $emailInfo->addTo($this->getCustomerEmail(), $customerName);
            if ($copyTo && $copyMethod == 'bcc') {
                // Add bcc to customer email
                foreach ($copyTo as $email) {
                    $emailInfo->addBcc($email);
                }
            }
            $mailer->addEmailInfo($emailInfo);
        }

        // Email copies are sent as separated emails if their copy method is
        // 'copy' or a customer should not be notified
        if ($copyTo && ($copyMethod == 'copy' || !$notifyCustomer)) {
            foreach ($copyTo as $email) {
                $emailInfo = Mage::getModel('core/email_info');
                $emailInfo->addTo($email);
                $mailer->addEmailInfo($emailInfo);
            }
        }

        // Set all required params and send emails
        $mailer->setSender(Mage::getStoreConfig(self::XML_PATH_UPDATE_EMAIL_IDENTITY, $storeId));
        $mailer->setStoreId($storeId);
        $mailer->setTemplateId($templateId);
        $mailer->setTemplateParams(array(
                'order'   => $this,
                'comment' => $comment,
                'billing' => $this->getBillingAddress()
            )
        );

        /** @var $emailQueue Mage_Core_Model_Email_Queue */
        $emailQueue = Mage::getModel('core/email_queue');
        $emailQueue->setEntityId($this->getId())
            ->setEntityType(self::ENTITY)
            ->setEventType(self::EMAIL_EVENT_NAME_UPDATE_ORDER)
            ->setIsForceCheck(!$forceMode);
        $mailer->send();

        return $this;
    }
}
